/****************************************************************************
** Meta object code from reading C++ file 'stringformatter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktouch-26.07.80/src/bindings/stringformatter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stringformatter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15StringFormatterE_t {};
} // unnamed namespace

template <> constexpr inline auto StringFormatter::qt_create_metaobjectdata<qt_meta_tag_ZN15StringFormatterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StringFormatter",
        "formatTime",
        "",
        "time",
        "formatTimeDiff",
        "from",
        "to",
        "formatAccuracy",
        "accuracy",
        "formatAccuracyDiff",
        "formatSign",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'formatTime'
        QtMocHelpers::MethodData<QString(const QTime &)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QTime, 3 },
        }}),
        // Method 'formatTimeDiff'
        QtMocHelpers::MethodData<QString(const QTime &, const QTime &)>(4, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QTime, 5 }, { QMetaType::QTime, 6 },
        }}),
        // Method 'formatAccuracy'
        QtMocHelpers::MethodData<QString(qreal)>(7, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QReal, 8 },
        }}),
        // Method 'formatAccuracyDiff'
        QtMocHelpers::MethodData<QString(qreal, qreal)>(9, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QReal, 5 }, { QMetaType::QReal, 6 },
        }}),
        // Method 'formatSign'
        QtMocHelpers::MethodData<QString(qreal)>(10, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QReal, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StringFormatter, qt_meta_tag_ZN15StringFormatterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StringFormatter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15StringFormatterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15StringFormatterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15StringFormatterE_t>.metaTypes,
    nullptr
} };

void StringFormatter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StringFormatter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->formatTime((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->formatTimeDiff((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTime>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->formatAccuracy((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->formatAccuracyDiff((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->formatSign((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *StringFormatter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StringFormatter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15StringFormatterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StringFormatter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
